# Changelog
All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/),
and this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).

## [Unreleased]

## [0.1.0-alpha.13](https://github.com/lox-space/lox/compare/lox-ephem-v0.1.0-alpha.12...lox-ephem-v0.1.0-alpha.13) - 2026-03-02

### Other

- updated the following local packages: lox-core, lox-time, lox-units, lox-bodies

## [0.1.0-alpha.12](https://github.com/lox-space/lox/compare/lox-ephem-v0.1.0-alpha.11...lox-ephem-v0.1.0-alpha.12) - 2026-03-02

### Fixed

- fix lints in tests

## [0.1.0-alpha.11](https://github.com/lox-space/lox/compare/lox-ephem-v0.1.0-alpha.10...lox-ephem-v0.1.0-alpha.11) - 2026-02-27

### Other

- updated the following local packages: lox-core, lox-time, lox-units, lox-bodies

## [0.1.0-alpha.10](https://github.com/lox-space/lox/compare/lox-ephem-v0.1.0-alpha.9...lox-ephem-v0.1.0-alpha.10) - 2026-02-25

### Other

- *(lox-ephem)* clean-up API and style
- *(lox-ephem)* refactor ephemeris interface

## [0.1.0-alpha.9](https://github.com/lox-space/lox/compare/lox-ephem-v0.1.0-alpha.8...lox-ephem-v0.1.0-alpha.9) - 2026-02-22

### Added

- add optional serde feature

## [0.1.0-alpha.8](https://github.com/lox-space/lox/compare/lox-ephem-v0.1.0-alpha.7...lox-ephem-v0.1.0-alpha.8) - 2025-10-29

### Other

- move lox-units code to lox-core
- update SPDX headers and add helper script
- make Lox REUSE-compliant
- move type aliases to lox-units
- refactor all the things

## [0.1.0-alpha.7](https://github.com/lox-space/lox/compare/lox-ephem-v0.1.0-alpha.6...lox-ephem-v0.1.0-alpha.7) - 2025-09-19

### Other

- update nom and quick-xml

## [0.1.0-alpha.6](https://github.com/lox-space/lox/compare/lox-ephem-v0.1.0-alpha.5...lox-ephem-v0.1.0-alpha.6) - 2025-07-01

### Other

- fix clippy lints

## [0.1.0-alpha.5](https://github.com/lox-space/lox/compare/lox-ephem-v0.1.0-alpha.4...lox-ephem-v0.1.0-alpha.5) - 2025-06-19

### Other

- fix clippy lints

## [0.1.0-alpha.4](https://github.com/lox-space/lox/compare/lox-ephem-v0.1.0-alpha.3...lox-ephem-v0.1.0-alpha.4) - 2025-03-04

### Other

- update formatting

## [0.1.0-alpha.3](https://github.com/lox-space/lox/compare/lox-ephem-v0.1.0-alpha.2...lox-ephem-v0.1.0-alpha.3) - 2025-02-10

### Other

- update Cargo.toml dependencies

## [0.1.0-alpha.2](https://github.com/lox-space/lox/compare/lox-ephem-v0.1.0-alpha.1...lox-ephem-v0.1.0-alpha.2) - 2024-12-18

### Other

- fix clippy lints

## [0.1.0-alpha.1](https://github.com/lox-space/lox/compare/lox-ephem-v0.1.0-alpha.0...lox-ephem-v0.1.0-alpha.1) - 2024-11-12

### Added

- *(lox-orbits)* implement frame and origin change for Python classes
- *(lox-orbits)* implement origin change for `State`

## [0.1.0-alpha.0](https://github.com/lox-space/lox/releases/tag/lox-ephem-v0.1.0-alpha.0) - 2024-07-19

### Other
- Rename lox-utils to lox-math because the former is taken ([#146](https://github.com/lox-space/lox/pull/146))
- Add crate descriptions ([#145](https://github.com/lox-space/lox/pull/145))
- Align versions ([#143](https://github.com/lox-space/lox/pull/143))
- Release preparation ([#140](https://github.com/lox-space/lox/pull/140))
- Implement `DeltaUt1Tai` provider ([#101](https://github.com/lox-space/lox/pull/101))
- Hoist shared constants and type aliases ([#84](https://github.com/lox-space/lox/pull/84))
- Core No More ([#68](https://github.com/lox-space/lox/pull/68))
